![saluki](https://github.com/rerpha/saluki/blob/main/resources/logo.png?raw=True)

Serialise/deserialise flatbuffers blobs from kafka

## install 

`pip install saluki`

## developer setup 
`pip install .[dev]`

